==> home-made-io-fastmag-sync-m2-0.12.2-91699c.zip: Model/Config/Provider/DirectSql.php <==
<?php
/*******************************************************************************
 * Created by HOMEMADE.IO SAS.
 * Fastmag Sync  -  Connect Fastmag with your Magento
 *
 * Copyright (C) HOMEMADE.IO SAS, Inc - All Rights Reserved
 *
 * @author    Simon Laubet-Xavier <simon.laubetxavier@home-made.io>
 * @copyright 2020-2020 HOMEMADE.IO SAS
 * @date      2020-04-29
 ******************************************************************************/

namespace Fastmag\Sync\Model\Config\Provider;

use Fastmag\Sync\Model\Config\Provider;
use Magento\Store\Model\ScopeInterface;

/**
 * Class DirectSql
 *
 * Class giving access for direct SQL connection
 */
class DirectSql extends Provider
{
    /** @var string */
    public const XML_CONFIG_PREFIX = 'fastmag_sync_connect/proxy';

    /** @var string */
    public const XML_CONFIG_HOST = 'host';

    /** @var string */
    public const XML_CONFIG_PORT = 'port';

    /** @var string */
    public const XML_CONFIG_USER = 'user';

    /** @var string */
    public const XML_CONFIG_PASSWORD = 'password';

    /**
     * An alias for scope config with default scope type SCOPE_STORE
     *
     * @param string $key
     * @param string $scopeType
     *
     * @return string|null
     */
    public function getValue($key, $scopeType = ScopeInterface::SCOPE_STORE)
    {
        return parent::getValue(self::XML_CONFIG_PREFIX . '/' . $key, $scopeType);
    }

    /**
     * Get host
     *
     * @param $scopeType
     *
     * @return string|null
     */
    public function getHost($scopeType = ScopeInterface::SCOPE_STORE)
    {
        return $this->getValue(self::XML_CONFIG_HOST, $scopeType);
    }

    /**
     * Get port
     *
     * @param $scopeType
     *
     * @return string|null
     */
    public function getPort($scopeType = ScopeInterface::SCOPE_STORE)
    {
        return $this->getValue(self::XML_CONFIG_PORT, $scopeType);
    }

    /**
     * Get user
     *
     * @param $scopeType
     *
     * @return string|null
     */
    public function getUser($scopeType = ScopeInterface::SCOPE_STORE)
    {
        return $this->getValue(self::XML_CONFIG_USER, $scopeType);
    }

    /**
     * Get password
     *
     * @param $scopeType
     *
     * @return string|null
     */
    public function getPassword($scopeType = ScopeInterface::SCOPE_STORE)
    {
        return $this->getValue(self::XML_CONFIG_PASSWORD, $scopeType);
    }
}

==> home-made-io-fastmag-sync-m2-0.24.1-03b91c.zip: Model/Config/Provider/DirectSql.php <==
<?php
/*******************************************************************************
 * Created by HOMEMADE.IO SAS.
 * Fastmag Sync  -  Connect Fastmag with your Magento
 *
 * Copyright (C) HOMEMADE.IO SAS, Inc - All Rights Reserved
 *
 * @author    Simon Laubet-Xavier <simon.laubetxavier@home-made.io>
 * @copyright 2020-2021 HOMEMADE.IO SAS
 * @date      2021-05-28
 ******************************************************************************/

namespace Fastmag\Sync\Model\Config\Provider;

use Fastmag\Sync\Model\Config;
use Fastmag\Sync\Model\Config\Provider;
use Magento\Store\Model\ScopeInterface;

/**
 * Class DirectSql
 *
 * Class giving access for direct SQL connection
 */
class DirectSql extends Provider
{
    /** @var string */
    public const XML_CONFIG_PREFIX = 'fastmag_sync_connect/proxy';

    /** @var string */
    public const XML_CONFIG_HOST = 'host';

    /** @var string */
    public const XML_CONFIG_PORT = 'port';

    /** @var string */
    public const XML_CONFIG_USER = 'user';

    /** @var string */
    public const XML_CONFIG_PASSWORD = 'password';

    /**
     * An alias for scope config with default scope type SCOPE_STORE
     *
     * @param string $key
     * @param string $scopeType
     *
     * @return string|null
     */
    public function getValue($key, $scopeType = ScopeInterface::SCOPE_STORE)
    {
        return parent::getValue(self::XML_CONFIG_PREFIX . '/' . $key, $scopeType);
    }

    /**
     * Get host
     *
     * @param $scopeType
     *
     * @return string|null
     */
    public function getHost($scopeType = ScopeInterface::SCOPE_STORE)
    {
        return $this->getValue(self::XML_CONFIG_HOST, $scopeType);
    }

    /**
     * Get port
     *
     * @param $scopeType
     *
     * @return string|null
     */
    public function getPort($scopeType = ScopeInterface::SCOPE_STORE)
    {
        return $this->getValue(self::XML_CONFIG_PORT, $scopeType);
    }

    /**
     * Get user
     *
     * @param $scopeType
     *
     * @return string|null
     */
    public function getUser($scopeType = ScopeInterface::SCOPE_STORE)
    {
        return $this->getValue(self::XML_CONFIG_USER, $scopeType);
    }

    /**
     * Get password
     *
     * @param $scopeType
     *
     * @return string|null
     */
    public function getPassword($scopeType = ScopeInterface::SCOPE_STORE)
    {
        return $this->getValue(self::XML_CONFIG_PASSWORD, $scopeType);
    }

    /**
     * Get database name
     *
     * @param $scopeType
     *
     * @return string|null
     */
    public function getDatabase($scopeType = ScopeInterface::SCOPE_STORE)
    {
        return 'fastmag_' . strtolower($this->scopeConfig->getValue(Config::XML_PATH_CONNECT_API_CHAIN, $scopeType));
    }
}
